Learn R Programming

semds (version 0.9-6)

AvaRegions: Avalanche Problems Across Canadian Mountain Regions

Description

Contains dissimilarity matrices across mountain regions in British Columbia and BC for each of the 13 avalanche problems. The extended Dice coefficient was used on problem prevalences in order to compute the dissimilarities. This computation was carried out for each elevation band (alpine, treeline, below treeline) separately.

Usage

data(AvaRegions)

Arguments

Format

For each elevation band a list of dissimilarity matrices is provided for the following avalanche problems:

DeepP

Deep persistent slab

Ldry

Loose dry avalanche

Lwet

Loose wet & persistent slab

NoProbs

No avalanche problems

Pers

Persistent slab

PersPlus

Persistent slab plus

Spring

Spring-like

Storm

Storm slab

StormDeepP

Storm & deep persistent slab

StormPers

Storm & persistent slab

StormWind

Storm & wind slab

StormWindPers

Storm, wind, & persistent slab

Wind

Wind slab

References

Shandro, B., & Haegeli, P. (2018). Characterizing the nature and variability of avalanche hazard in western canada. Natural Hazards and Earth System Sciences, 18, 1141-1158.

Examples

Run this code
# NOT RUN {
data(AvaRegions)
str(alpD)             ## alpine
str(tlD)              ## treeline 
str(btlD)             ## below treeline
# }

Run the code above in your browser using DataLab