Learn R Programming

semds (version 0.9-6)

Recreation: Recreation Data

Description

Ten subjects were asked to judge differences, in terms of his/her own preference, between 15 forms of recreations. Each particular subject judged every one of 105 pairs of forms of recreation in a dissimilarity scale of 25 categories (numbered from 1 to 25). In this data set, only the lower right triangle excluding the diagonal was originally considered for each dissimilarity matrix because the natural asymmetry in judements. Recreations forms were Concert (Ct), Museum (M), Theater (T), Movie (Mv), Television (TV), Conference (Cf), Reading (R), Hockey (H), Ballet (B), Debate (D), Fashion (F), Doc-film (Df), Exhibition (E), Shopping (S) and Restaurant (Re).

Usage

data(Miller)

Arguments

Format

A list of dissimilarity matrices.

References

Ramsay (1997).

Examples

Run this code
# NOT RUN {
data(Recreation)
# }

Run the code above in your browser using DataLab